import { BaseOverride, LazyLoadedOverride, OpenNextConfig } from "@opennextjs/aws/types/open-next";
import type { IncrementalCache, Queue, TagCache } from "@opennextjs/aws/types/overrides";
export type Override<T extends BaseOverride> = "dummy" | T | LazyLoadedOverride<T>;
/**
 * Cloudflare specific overrides.
 *
 * See the [Caching documentation](https://opennext.js.org/cloudflare/caching))
 */
export type CloudflareOverrides = {
    /**
     * Sets the incremental cache implementation.
     */
    incrementalCache?: Override<IncrementalCache>;
    /**
     * Sets the tag cache implementation.
     */
    tagCache?: Override<TagCache>;
    /**
     * Sets the revalidation queue implementation
     */
    queue?: "direct" | Override<Queue>;
};
/**
 * Defines the OpenNext configuration that targets the Cloudflare adapter
 *
 * @param config options that enabled you to configure the application's behavior
 * @returns the OpenNext configuration object
 */
export declare function defineCloudflareConfig(config?: CloudflareOverrides): OpenNextConfig;
