import type { CacheValue, IncrementalCache, WithLastModified } from "@opennextjs/aws/types/overrides.js";
export declare const NAME = "cf-kv-incremental-cache";
export declare const BINDING_NAME = "NEXT_INC_CACHE_KV";
export type KeyOptions = {
    isFetch?: boolean;
    buildId?: string;
};
export declare function computeCacheKey(key: string, options: KeyOptions): string;
/**
 * Open Next cache based on Cloudflare KV.
 *
 * Note: The class is instantiated outside of the request context.
 * The cloudflare context and process.env are not initialized yet
 * when the constructor is called.
 */
declare class KVIncrementalCache implements IncrementalCache {
    readonly name = "cf-kv-incremental-cache";
    get<IsFetch extends boolean = false>(key: string, isFetch?: IsFetch): Promise<WithLastModified<CacheValue<IsFetch>> | null>;
    set<IsFetch extends boolean = false>(key: string, value: CacheValue<IsFetch>, isFetch?: IsFetch): Promise<void>;
    delete(key: string): Promise<void>;
    protected getKVKey(key: string, isFetch?: boolean): string;
}
declare const _default: KVIncrementalCache;
export default _default;
