import type { CacheValue, IncrementalCache, WithLastModified } from "@opennextjs/aws/types/overrides.js";
export declare const NAME = "cf-r2-incremental-cache";
export declare const BINDING_NAME = "NEXT_INC_CACHE_R2_BUCKET";
export declare const PREFIX_ENV_NAME = "NEXT_INC_CACHE_R2_PREFIX";
export declare const DEFAULT_PREFIX = "incremental-cache";
export type KeyOptions = {
    isFetch?: boolean;
    directory?: string;
    buildId?: string;
};
export declare function computeCacheKey(key: string, options: KeyOptions): string;
/**
 * An instance of the Incremental Cache that uses an R2 bucket (`NEXT_INC_CACHE_R2_BUCKET`) as it's
 * underlying data store.
 *
 * The directory that the cache entries are stored in can be configured with the `NEXT_INC_CACHE_R2_PREFIX`
 * environment variable, and defaults to `incremental-cache`.
 */
declare class R2IncrementalCache implements IncrementalCache {
    readonly name = "cf-r2-incremental-cache";
    get<IsFetch extends boolean = false>(key: string, isFetch?: IsFetch): Promise<WithLastModified<CacheValue<IsFetch>> | null>;
    set<IsFetch extends boolean = false>(key: string, value: CacheValue<IsFetch>, isFetch?: IsFetch): Promise<void>;
    delete(key: string): Promise<void>;
    protected getR2Key(key: string, isFetch?: boolean): string;
}
declare const _default: R2IncrementalCache;
export default _default;
